@@ -85,12 +85,13 @@ class GCEMetadata:
 
     def run(self):
         """ Runs the server """
+        is_debug = getattr(logging, self.verbosity) <= logging.DEBUG
+        stderr = sys.stderr if is_debug else PIPE
         server = run([
             'uwsgi',
             '--http', '=0',
             '--shared-socket', GCEMetadata.IP + ':80',
             '--uid', 'nobody', '--gid', 'nobody',
-            '--manage-script-name',
             '--wsgi', 'google_yubikey.metadata:create_uwsgi_app()',
             '--set', f'slot={self.slot.value}',
             '--set', f'prompt_management_key={self.prompt_management_key}',
@@ -101,9 +102,9 @@ class GCEMetadata:
             '--set', f'verbosity={self.verbosity}',
             '--processes', '1',
             '--honour-stdin',
-        ], stdout=sys.stdout, stderr=PIPE, text=True, check=False)
+        ], stdout=sys.stdout, stderr=stderr, text=True, check=False)
 
-        if server.returncode != 0:
+        if not is_debug and server.returncode != 0:
             print(server.stderr)
 
 
@@ -207,7 +208,7 @@ def create_uwsgi_app():
     """ Sets up uWSGI app for GCE metadata server """
     opts = UWSGIOpts()
     log = _get_log('gce_metadata', opts.verbosity)
-    yubikey = get_yubikey()
+    yubikey = get_yubikey(sys.stdout)
     app = Flask(__name__)
 
     @app.before_request
@@ -215,12 +216,12 @@ def create_uwsgi_app():
         log.debug(request.method + ' ' + request.path)
         if request.path == '/':
             return None
-        elif request.headers.get('X-Forwarded-For') or \
-                request.headers.get('Metadata-Flavor') != 'Google' or \
-                request.headers.get('Host') not in GCEMetadata.HOSTS + [GCEMetadata.IP]:
+        headers = request.headers
+        if headers.get('X-Forwarded-For') or \
+                headers.get('Metadata-Flavor') != 'Google' or \
+                headers.get('Host') not in GCEMetadata.HOSTS + [GCEMetadata.IP]:
             return abort(401)
-        else:
-            return None
+        return None
 
     @app.after_request
     def _add_response_headers(response: Response):
